@@ -29,6 +29,9 @@ def operation(self, method="mul", ff=None, var=None):
     This is used by add etc.
     """
 
+    if len(self) == 0:
+        raise ValueError("Failure due to empty dataset!")
+
     # If the dataset has to be merged,
     # then this operation will not work without running it first
     if self._merged:
@@ -48,7 +51,7 @@ def operation(self, method="mul", ff=None, var=None):
 
     # make sure the ff file is not removed from safe list in subsequent
     # actions prior to running
-    if (ff is not None) and (session_info["lazy"]) and (cdo_version() != "1.9.3"):
+    if (ff is not None) and (session_info["lazy"]) :
         append_safe(ff)
         self._safe.append(ff)
 
@@ -89,7 +92,7 @@ def operation(self, method="mul", ff=None, var=None):
 
     # run the command if not lazy
 
-    if (session_info["lazy"] is False) or (cdo_version in ["1.9.3"]):
+    if (session_info["lazy"] is False):
 
         new_files = []
         new_commands = []
