@@ -1250,7 +1250,9 @@ class DataSet(object):
     from nctoolkit.ensembles import ensemble_max
     from nctoolkit.ensembles import ensemble_min
     from nctoolkit.ensembles import ensemble_range
+    from nctoolkit.ensembles import ensemble_stdev
     from nctoolkit.ensembles import ensemble_sum
+    from nctoolkit.ensembles import ensemble_var
 
     from nctoolkit.ensembles import ensemble_percentile
 
@@ -1329,6 +1331,7 @@ class DataSet(object):
     from nctoolkit.temporal_stat import tmedian
     from nctoolkit.temporal_stat import tmin
     from nctoolkit.temporal_stat import trange
+    from nctoolkit.temporal_stat import tvar
     from nctoolkit.temporal_stat import tvariance
     from nctoolkit.temporal_stat import tstdev
     from nctoolkit.temporal_stat import tsum
