@@ -2,6 +2,9 @@ import subprocess
 
 
 def nc_times(ff):
+    """
+    Function to return times available in a netCDF file
+    """
 
     cdo_result = subprocess.run(
         f"cdo showtimestamp {ff}",
@@ -16,9 +19,27 @@ def nc_times(ff):
     return cdo_result
 
 
+def nc_format(ff):
+    """
+    Function to return the format of a netCDF file
+    """
+
+    cdo_result = subprocess.run(
+        f"cdo showformat {ff}",
+        shell=True,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+    )
+    cdo_result = str(cdo_result.stdout).replace("\\n", "")
+    cdo_result = cdo_result.replace("b'", "").strip()
+    cdo_result = cdo_result.replace("'", "").strip()
+    cdo_result = cdo_result.split()
+    return cdo_result
+
+
 def nc_levels(ff):
     """
-    Method to get the depths available in a netcdf file
+    Function to get the depths available in a netCDF file
     """
 
     cdo_result = subprocess.run(
@@ -38,6 +59,10 @@ def nc_levels(ff):
 
 
 def nc_years(ff):
+    """
+    Function to get the years available in a netCDF file
+    """
+
     all_years = []
     cdo_result = subprocess.run(
         f"cdo showyear {ff}", shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE
@@ -54,6 +79,10 @@ def nc_years(ff):
 
 
 def nc_variables(ff):
+    """
+    Function to get the variables available in a netCDF file
+    """
+
     cdo_result = subprocess.run(
         f"cdo showname {ff}", shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE
     )
@@ -67,6 +96,9 @@ def nc_variables(ff):
 
 
 def nc_months(ff):
+    """
+    Function to get the months available in a netCDF file
+    """
 
     cdo_result = subprocess.run(
         f"cdo showmon {ff}",
